searchData={"items":[{"type":"module","title":"Trogon.Error","doc":"Universal Error Specification implementation for Elixir.\n\nThis module provides a `use` macro to define structured exceptions\nfollowing the Universal Error Specification ADR.","ref":"Trogon.Error.html"},{"type":"module","title":"Usage - Trogon.Error","doc":"defmodule MyApp.NotFoundError do\n      use Trogon.Error,\n        domain: \"com.myapp.mydomain\",\n        reason: \"not_found\",\n        message: \"The {resource} was not found\"\n    end","ref":"Trogon.Error.html#module-usage"},{"type":"module","title":"Creating Errors - Trogon.Error","doc":"MyApp.NotFoundError.new!(\n      metadata: Trogon.Error.Metadata.new(%{resource: \"user\"})\n    )","ref":"Trogon.Error.html#module-creating-errors"},{"type":"macro","title":"Trogon.Error.__using__/1","doc":"Defines an error module with the given options.","ref":"Trogon.Error.html#__using__/1"},{"type":"macro","title":"Options - Trogon.Error.__using__/1","doc":"* `:domain` (`t:String.t/0`) - Required. The error domain identifying the service or component that generated the error\n\n* `:reason` (`t:String.t/0`) - Required. A unique identifier for the specific error within the domain\n\n* `:message` - The error message, either an atom that maps to a standard message or a custom string\n\n* `:metadata` - Default metadata to be merged with runtime metadata. Values will be automatically converted to MetadataValue structs. The default value is `%{}`.\n\n* `:code` - The standard error code The default value is `:unknown`.\n\n* `:visibility` - Whether the error should be visible to end users or kept internal The default value is `:internal`.\n\n* `:help` (`t:map/0`) - Help information with links to documentation\n\n  * `:links` (list of `t:map/0`)","ref":"Trogon.Error.html#__using__/1-options"},{"type":"type","title":"Trogon.Error.code/0","doc":"","ref":"Trogon.Error.html#t:code/0"},{"type":"type","title":"Trogon.Error.debug_info/0","doc":"","ref":"Trogon.Error.html#t:debug_info/0"},{"type":"type","title":"Trogon.Error.error_opts/0","doc":"","ref":"Trogon.Error.html#t:error_opts/0"},{"type":"type","title":"Trogon.Error.help/0","doc":"","ref":"Trogon.Error.html#t:help/0"},{"type":"type","title":"Trogon.Error.help_link/0","doc":"","ref":"Trogon.Error.html#t:help_link/0"},{"type":"type","title":"Trogon.Error.id/0","doc":"","ref":"Trogon.Error.html#t:id/0"},{"type":"macro","title":"Trogon.Error.is_trogon_error?/1","doc":"Checks if a term is a Trogon error.","ref":"Trogon.Error.html#is_trogon_error?/1"},{"type":"macro","title":"Examples - Trogon.Error.is_trogon_error?/1","doc":"iex> error = TestSupport.TestError.new!()\n    iex> require Trogon.Error\n    iex> Trogon.Error.is_trogon_error?(error)\n    true\n\n    iex> require Trogon.Error\n    iex> Trogon.Error.is_trogon_error?(%{})\n    false","ref":"Trogon.Error.html#is_trogon_error?/1-examples"},{"type":"type","title":"Trogon.Error.localized_message/0","doc":"","ref":"Trogon.Error.html#t:localized_message/0"},{"type":"function","title":"Trogon.Error.metadata/0","doc":"See  Trogon.Error.Metadata.new/0 .","ref":"Trogon.Error.html#metadata/0"},{"type":"type","title":"Trogon.Error.metadata/0","doc":"","ref":"Trogon.Error.html#t:metadata/0"},{"type":"type","title":"Trogon.Error.retry_info/0","doc":"","ref":"Trogon.Error.html#t:retry_info/0"},{"type":"type","title":"Trogon.Error.retry_info_duration/0","doc":"","ref":"Trogon.Error.html#t:retry_info_duration/0"},{"type":"type","title":"Trogon.Error.source_id/0","doc":"","ref":"Trogon.Error.html#t:source_id/0"},{"type":"type","title":"Trogon.Error.subject/0","doc":"","ref":"Trogon.Error.html#t:subject/0"},{"type":"type","title":"Trogon.Error.t/1","doc":"","ref":"Trogon.Error.html#t:t/1"},{"type":"type","title":"Trogon.Error.time/0","doc":"","ref":"Trogon.Error.html#t:time/0"},{"type":"function","title":"Trogon.Error.to_code_int/1","doc":"Converts an atom to an integer code.","ref":"Trogon.Error.html#to_code_int/1"},{"type":"function","title":"Examples - Trogon.Error.to_code_int/1","doc":"iex> Trogon.Error.to_code_int(:cancelled)\n    1\n    iex> err = TestSupport.InvalidCurrencyError.new!()\n    ...> Trogon.Error.to_code_int(err)\n    2","ref":"Trogon.Error.html#to_code_int/1-examples"},{"type":"function","title":"Trogon.Error.to_msg/1","doc":"","ref":"Trogon.Error.html#to_msg/1"},{"type":"function","title":"Trogon.Error.validate_options!/1","doc":"Validates compile-time options using NimbleOptions.","ref":"Trogon.Error.html#validate_options!/1"},{"type":"function","title":"Examples - Trogon.Error.validate_options!/1","doc":"iex> opts = [domain: \"com.test\", reason: \"TEST\"]\n    iex> validated = Trogon.Error.validate_options!(opts)\n    iex> validated[:domain]\n    \"com.test\"\n    iex> validated[:reason]\n    \"TEST\"","ref":"Trogon.Error.html#validate_options!/1-examples"},{"type":"type","title":"Trogon.Error.visibility/0","doc":"","ref":"Trogon.Error.html#t:visibility/0"},{"type":"module","title":"Trogon.Error.Metadata","doc":"A structured container for error metadata with support for visibility controls.\n\nThis module provides a wrapper around metadata entries, where each entry\nis a `MetadataValue` struct containing both the value and its visibility level.\n\nImplements the `Access` behavior for convenient map-like access to metadata entries.","ref":"Trogon.Error.Metadata.html"},{"type":"module","title":"Examples - Trogon.Error.Metadata","doc":"iex> metadata = Trogon.Error.Metadata.new(%{\"user_id\" => \"123\", \"action\" => \"login\"})\n    iex> metadata[\"user_id\"].value\n    \"123\"\n    iex> metadata[\"user_id\"].visibility\n    :internal","ref":"Trogon.Error.Metadata.html#module-examples"},{"type":"function","title":"Trogon.Error.Metadata.fetch/2","doc":"Fetches a metadata value by key.","ref":"Trogon.Error.Metadata.html#fetch/2"},{"type":"function","title":"Examples - Trogon.Error.Metadata.fetch/2","doc":"iex> metadata = Trogon.Error.Metadata.new(%{\"user_id\" => \"123\"})\n    iex> Trogon.Error.Metadata.fetch(metadata, \"user_id\")\n    {:ok, %Trogon.Error.MetadataValue{value: \"123\", visibility: :internal}}\n\n    iex> metadata = Trogon.Error.Metadata.new(%{})\n    iex> Trogon.Error.Metadata.fetch(metadata, \"missing\")\n    :error","ref":"Trogon.Error.Metadata.html#fetch/2-examples"},{"type":"function","title":"Trogon.Error.Metadata.get_and_update/3","doc":"Gets and updates a metadata entry.","ref":"Trogon.Error.Metadata.html#get_and_update/3"},{"type":"function","title":"Examples - Trogon.Error.Metadata.get_and_update/3","doc":"iex> metadata = Trogon.Error.Metadata.new(%{\"count\" => \"1\"})\n    iex> {old_value, new_metadata} = Trogon.Error.Metadata.get_and_update(metadata, \"count\", fn old ->\n    ...>   new_value = %Trogon.Error.MetadataValue{value: \"2\", visibility: :internal}\n    ...>   {old, new_value}\n    ...> end)\n    iex> old_value.value\n    \"1\"\n    iex> new_metadata[\"count\"].value\n    \"2\"","ref":"Trogon.Error.Metadata.html#get_and_update/3-examples"},{"type":"macro","title":"Trogon.Error.Metadata.is_empty_metadata/1","doc":"Guard that checks if metadata is empty (has no entries).","ref":"Trogon.Error.Metadata.html#is_empty_metadata/1"},{"type":"macro","title":"Examples - Trogon.Error.Metadata.is_empty_metadata/1","doc":"iex> import Trogon.Error.Metadata, only: [is_empty_metadata: 1]\n    iex> empty = Trogon.Error.Metadata.new()\n    iex> is_empty_metadata(empty)\n    true\n\n    iex> import Trogon.Error.Metadata, only: [is_empty_metadata: 1]\n    iex> with_data = Trogon.Error.Metadata.new(%{\"key\" => \"value\"})\n    iex> is_empty_metadata(with_data)\n    false","ref":"Trogon.Error.Metadata.html#is_empty_metadata/1-examples"},{"type":"function","title":"Trogon.Error.Metadata.merge/2","doc":"Merges two Metadata structs, with the second taking precedence for duplicate keys.","ref":"Trogon.Error.Metadata.html#merge/2"},{"type":"function","title":"Examples - Trogon.Error.Metadata.merge/2","doc":"iex> metadata1 = Trogon.Error.Metadata.new(%{\"user_id\" => \"123\", \"action\" => \"login\"})\n    iex> metadata2 = Trogon.Error.Metadata.new(%{\"user_id\" => \"456\", \"session\" => \"abc\"})\n    iex> merged = Trogon.Error.Metadata.merge(metadata1, metadata2)\n    iex> merged[\"user_id\"].value\n    \"456\"\n    iex> map_size(merged.entries)\n    3","ref":"Trogon.Error.Metadata.html#merge/2-examples"},{"type":"function","title":"Trogon.Error.Metadata.new/0","doc":"Creates a new empty Metadata struct.","ref":"Trogon.Error.Metadata.html#new/0"},{"type":"function","title":"Examples - Trogon.Error.Metadata.new/0","doc":"iex> Trogon.Error.Metadata.new()\n    %Trogon.Error.Metadata{entries: %{}}","ref":"Trogon.Error.Metadata.html#new/0-examples"},{"type":"function","title":"Trogon.Error.Metadata.new/1","doc":"Creates a new Metadata struct from a map of entries.\n\nAccepts various formats for metadata values:\n- Simple values (converted to MetadataValue with :internal visibility)\n- Tuples with explicit visibility: `{value, visibility}`\n- Pre-existing MetadataValue structs","ref":"Trogon.Error.Metadata.html#new/1"},{"type":"function","title":"Examples - Trogon.Error.Metadata.new/1","doc":"iex> metadata = Trogon.Error.Metadata.new(%{\"user_id\" => \"123\", \"secret\" => {\"api-key\", :private}})\n    iex> metadata[\"user_id\"].visibility\n    :internal\n    iex> metadata[\"secret\"].visibility\n    :private","ref":"Trogon.Error.Metadata.html#new/1-examples"},{"type":"function","title":"Trogon.Error.Metadata.pop/2","doc":"Pops a metadata entry by key.","ref":"Trogon.Error.Metadata.html#pop/2"},{"type":"function","title":"Examples - Trogon.Error.Metadata.pop/2","doc":"iex> metadata = Trogon.Error.Metadata.new(%{\"user_id\" => \"123\", \"action\" => \"login\"})\n    iex> {value, new_metadata} = Trogon.Error.Metadata.pop(metadata, \"user_id\")\n    iex> value.value\n    \"123\"\n    iex> map_size(new_metadata.entries)\n    1","ref":"Trogon.Error.Metadata.html#pop/2-examples"},{"type":"type","title":"Trogon.Error.Metadata.t/0","doc":"","ref":"Trogon.Error.Metadata.html#t:t/0"},{"type":"module","title":"Trogon.Error.MetadataValue","doc":"Represents a metadata entry with both value and visibility level.\n\nEach metadata entry in a Trogon error contains not just the value,\nbut also its visibility level which determines who can see this metadata.","ref":"Trogon.Error.MetadataValue.html"},{"type":"module","title":"Visibility Levels - Trogon.Error.MetadataValue","doc":"- `:internal` - Only visible to internal systems and developers (default)\n- `:private` - Visible to authenticated users but not public\n- `:public` - Visible to everyone including end users","ref":"Trogon.Error.MetadataValue.html#module-visibility-levels"},{"type":"module","title":"Examples - Trogon.Error.MetadataValue","doc":"iex> Trogon.Error.MetadataValue.new(\"secret data\", :private)\n    %Trogon.Error.MetadataValue{value: \"secret data\", visibility: :private}\n\n    iex> Trogon.Error.MetadataValue.new(123)\n    %Trogon.Error.MetadataValue{value: \"123\", visibility: :internal}","ref":"Trogon.Error.MetadataValue.html#module-examples"},{"type":"function","title":"Trogon.Error.MetadataValue.new/1","doc":"Creates a new MetadataValue with the given value and default visibility.","ref":"Trogon.Error.MetadataValue.html#new/1"},{"type":"function","title":"Examples - Trogon.Error.MetadataValue.new/1","doc":"iex> Trogon.Error.MetadataValue.new(\"secret\")\n    %Trogon.Error.MetadataValue{value: \"secret\", visibility: :internal}","ref":"Trogon.Error.MetadataValue.html#new/1-examples"},{"type":"function","title":"Trogon.Error.MetadataValue.new/2","doc":"Creates a new MetadataValue with the given value and visibility.\n\nThe value will be converted to a string if it's not already one.","ref":"Trogon.Error.MetadataValue.html#new/2"},{"type":"function","title":"Examples - Trogon.Error.MetadataValue.new/2","doc":"iex> Trogon.Error.MetadataValue.new(\"secret\", :private)\n    %Trogon.Error.MetadataValue{value: \"secret\", visibility: :private}\n\n    iex> Trogon.Error.MetadataValue.new(123, :public)\n    %Trogon.Error.MetadataValue{value: \"123\", visibility: :public}","ref":"Trogon.Error.MetadataValue.html#new/2-examples"},{"type":"type","title":"Trogon.Error.MetadataValue.t/0","doc":"","ref":"Trogon.Error.MetadataValue.html#t:t/0"},{"type":"type","title":"Trogon.Error.MetadataValue.visibility/0","doc":"","ref":"Trogon.Error.MetadataValue.html#t:visibility/0"},{"type":"extras","title":"Trogon.Error","doc":"# Trogon.Error","ref":"readme.html"},{"type":"extras","title":"Documentation - Trogon.Error","doc":"","ref":"readme.html#documentation"},{"type":"extras","title":"References - Trogon.Error","doc":"- [API Reference](api-reference.html)","ref":"readme.html#references"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Changelog","doc":"## [0.3.0](https://github.com/straw-hat-team/beam-monorepo/compare/trogon_error@v0.2.0...trogon_error@v0.3.0) (2025-06-30)","ref":"changelog.html#unreleased"},{"type":"extras","title":"Features - Changelog","doc":"* **trogon_error:** Update implementation to follow latest version of the ADR ([#210](https://github.com/straw-hat-team/beam-monorepo/issues/210)) ([c0bac39](https://github.com/straw-hat-team/beam-monorepo/commit/c0bac3928c52c5543880101d2c3311b5cc15dce3))","ref":"changelog.html#features"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"- Add `Trogon.Error.is_trogon_error?/1` guard.","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.1 - Changelog","doc":"- Fix `t:Trogon.Error.error_opts/0` type.","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"- Initial release.","ref":"changelog.html#v0-1-0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}